/***********************************************
 * Licensed Materials - Property of IBM
 * 
 * 5724-R31, 5655-S30
 *
 * (C) Copyright IBM Corp. 2002, 2006 All Rights Reserved.
 * (C) Copyright Webify Solutions, Inc. 2002, 2006 All Rights Reserved.
 * 
 * US Government Users Restricted Rights - Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 ***********************************************
 */
package com.ibm.websphere.fabric.insurance.pc.contextextractor;

import java.util.Map;

import com.ibm.websphere.fabric.da.PendingRequest;
import com.ibm.websphere.fabric.da.context.Context;
import com.ibm.websphere.fabric.da.plugin.ContextExtractor;
import com.ibm.websphere.fabric.da.plugin.UnexpectedContentException;
import com.ibm.websphere.fabric.da.types.TypedValue;
import com.ibm.websphere.fabric.insurance.pc.service.util.BpelContextHandler;
import com.ibm.websphere.fabric.insurance.pc.service.util.IConstants;

/**
 * Sets the state based assertion for the current interface.
 * 
 * @author govindm
 */
public class StateAssertionContextExtractorImpl implements ContextExtractor {

    /**
     * URI for state based assertion.
     */
    private static final String STATE_BASED_ASSERTION = "http://www.ibm.com/websphere/fabric/insurance/pc/iaa/bom/assertions#hasStateCd";
    
	private static final String FABRIC_GOVERNANCE = "fc://fabric/governance/fabricproject-inst#3c765894-632c-4866-810a-ac74e16b16b0";

	private static final String FABRIC_GOVERNANCE_VALUE = "http://www.webifysolutions.com/2005/10/catalog/governance#FabricProject";


    /**
     * Default constructor.
     */
    public StateAssertionContextExtractorImpl() {

        super();
    }

    /**
     * Return a reference to the component service instance for this
     * implementation class. This method should be used when passing this
     * service to a partner reference or if you want to invoke this component
     * service asynchronously.
     * 
     * @generated (com.ibm.wbit.java)
     */
//    private ContextExtractor getMyService() {
//        return (ContextExtractor) ServiceManager.INSTANCE.locateService("self");
//    }

    /**
     * @see com.ibm.websphere.fabric.da.plugin.ContextExtractor#
     *      extractContext(PendingRequest arg0)
     */
    public Context extractContext(PendingRequest pendingRequest) throws UnexpectedContentException {

        Context context = pendingRequest.getContext();
        //logger.info("context.:" + context.getSelectionPropertyNames());

        // get the state value
        Map map = BpelContextHandler.getContextProperties();
        String state = null;

        if (map != null) {
            state = (String) map.get(IConstants.STATE);
        }

        if (state != null) {
            TypedValue assersionValue = new TypedValue(state);
            context.setSelectionProperty(STATE_BASED_ASSERTION, assersionValue);
        }

        //logger.info("State Based assertion set to context.");
        
		TypedValue governanceFabricProjectValue = new TypedValue(
				FABRIC_GOVERNANCE);

		context.setSelectionProperty(FABRIC_GOVERNANCE_VALUE,
				governanceFabricProjectValue);

        return context;

    }

}